/*******************************************************************************
	REPLICATION DO-FILE
	Johansson & Hultman "UN Peacekeeping and Protection from Sexual Violence"
	Journal of Conflict Resolution
	15 May 2018
*******************************************************************************/


clear all
use "johansson_hultman_jcr.dta"


*	Globals independent variables
global X1 L.troop1000_max L.police1000_max
global X2 e_mefree e_miferrat post1325 mission_duration L.bdbest_ln L.osv_ln pop_ln v2x_polyarchy rebstrength1 L.sv_prev
global X3 e_mefree e_miferrat post1325 mission_duration L.bdbest_ln L.osv_ln pop_ln v2x_polyarchy rebstrength1 L.svac_state L.svac_reb
global X6 e_mefree e_miferrat post1325 L.bdbest_ln L.osv_ln pop_ln v2x_polyarchy rebstrength1 L.sv_prev


************************************************
*	MODELS REPORTED IN THE PAPER
************************************************


*	TABLE 1
tab sv_23 un if actor_type==1, col chi2

*	TABLE 2
tab sv_23 un if actor_type==3, col chi2


*	TABLE 3
*	The Role of Size and Mandate, DV: Sexual Violence by State Forces 
eststo clear
eststo: quietly logit sv_23 $X1 L.nopoc $X2 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.troops_nopoc $X2 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.police_nopoc $X2 if actor_type==1, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) title(Table 3: The Role of Size and Mandate, DV: Sexual Violence by State Forces) nonumbers ///
mtitle("Model 1: Effect of mandate" "Model 2: Interacting mandate and troops" "Model 3: Interacting mandate and troops"), using gov_mandate.rtf ,replace

*	TABLE 4
*	The Role of Size and Mandate, DV: Sexual Violence by Rebel Groups
eststo clear
eststo: quietly logit sv_23 $X1 L.nopoc $X2 if actor_type==3, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.troops_nopoc $X2 if actor_type==3, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.police_nopoc $X2 if actor_type==3, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) title(Table 4: The Role of Size and Mandate, DV: Sexual Violence by Rebel Groups) nonumbers ///
mtitles("Model 1: Effect of mandate" "Model 2: Interacting mandate and troops" "Model 3: Interacting mandate and troops"), using reb_mandate.rtf ,replace

*	TABLE 5
*	The Role of Control, DV: Sexual Violence by State Forces
eststo clear
eststo: quietly logit sv_23 $X1 L.nocontrol_gov L.nopoc $X2 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_gov L.troops_nocontrolgov L.nopoc $X2 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_gov L.police_nocontrolgov L.nopoc $X2 if actor_type==1, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) title(Table 5: The Role of Control, DV: Sexual Violence by State Forces) nonumbers ///
mtitles("Model 1: Effect of control" "Model 2: Interacting control and troops" "Model 3: Interacting control and police"), using gov_control.rtf ,replace
 
*	TABLE 6
*	The Role of Control, DV: Sexual Violence by Rebel Groups
eststo clear
eststo: quietly logit sv_23 $X1 L.nocontrol_reb L.nopoc $X2 if actor_type==3, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_reb L.troops_nocontrolreb L.nopoc $X2 if actor_type==3, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_reb L.police_nocontrolreb L.nopoc $X2 if actor_type==3, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) title(Table 6: The Role of Control, DV: Sexual Violence by Rebel Groups) nonumbers ///
mtitles("Model 1: Effect of control" "Model 2: Interacting control and troops" "Model 3: Interacting control and police"), using reb_control.rtf ,replace


*	SUBSTANTIVE EFFECTS USING CLARIFY


*	substantive effects Table 4 model 3
sum l.police1000_max
estsimp logit sv_23 $X1 L.nopoc L.police_nopoc $X2 if actor_type==3, cl(conflictid)

setx l.police1000_max 0 L.nopoc 0  L.police_nopoc 0 (l.troop1000_max e_mefree e_miferrat mission_duration l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean ( rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.police1000_max 1 L.nopoc 0  L.police_nopoc 0 (l.troop1000_max e_mefree e_miferrat mission_duration l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean ( rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)

setx l.police1000_max 0 L.nopoc 1  L.police_nopoc 0 (l.troop1000_max e_mefree e_miferrat mission_duration l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean ( rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.police1000_max 1 L.nopoc 1  L.police_nopoc 1 (l.troop1000_max e_mefree e_miferrat mission_duration l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean ( rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)


*	substantive effects Table 5 model 2
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 

estsimp logit sv_23 $X1 L.nocontrol_gov L.troops_nocontrolgov L.nopoc $X2 if actor_type==1, cl(conflictid)

setx l.troop1000_max  0 L.nocontrol_gov 0  L.troops_nocontrolgov 0 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0  (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.troop1000_max 10 L.nocontrol_gov 0  L.troops_nocontrolgov 0 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)

setx l.troop1000_max 0 L.nocontrol_gov 1  L.troops_nocontrolgov 0 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.troop1000_max 10 L.nocontrol_gov 1  L.troops_nocontrolgov 1 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)


*	substantive effects Table 5 model 3
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 

estsimp logit sv_23 $X1 L.nocontrol_gov L.police_nocontrolgov L.nopoc $X2 if actor_type==1, cl(conflictid)

setx l.police1000_max 0 L.nocontrol_gov 0  L.police_nocontrolgov 0 (l.troop1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0  (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.police1000_max 1 L.nocontrol_gov 0  L.police_nocontrolgov 0 (l.troop1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)

setx l.police1000_max 0 L.nocontrol_gov 1  L.police_nocontrolgov 0 (l.troop1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.police1000_max 1 L.nocontrol_gov 1  L.police_nocontrolgov 1 (l.troop1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)



*	substantive effects Table 6 model 2
drop b1 b2 b3 b4 b5 b6 b7 b8 b9 b10 b11 b12 b13 b14 b15 b16 

estsimp logit sv_23 $X1 L.nocontrol_reb L.troops_nocontrolreb L.nopoc $X2 if actor_type==3, cl(conflictid)

setx l.troop1000_max 0 L.nocontrol_reb 0  L.troops_nocontrolreb 0 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.troop1000_max 10 L.nocontrol_reb 0  L.troops_nocontrolreb 0 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)

setx l.troop1000_max 0 L.nocontrol_reb 1  L.troops_nocontrolreb 0 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)
setx l.troop1000_max 10 L.nocontrol_reb 1  L.troops_nocontrolreb 10 (l.police1000_max e_mefree e_miferrat mission_duration  l.bdbest_ln l.osv_ln pop_ln v2x_polyarchy ) mean L.nopoc 0 (rebstrength1) median l.sv_prev 3 post1325 1
simqi, level(95)



*	FIGURE 1
*	The Marginal Effect of Rebel Control When Increasing the Number of Troops 

eststo clear
eststo: quietly logit sv_23 L.troop1000_max L.police1000_max L.nocontrol_reb L.troops_nocontrolreb L.nopoc $X2 if actor_type==3, cl(conflictid)
est sto m4

margins, dydx(L.nocontrol_reb) at(L.troop1000_max = (0(1)29)) predict(p) vsquish
marginsplot, recast(line) yline(0) title("") scheme(s1mono) xtitle("Number of troops") ytitle("Marginal effect of control") 



********************************************
*	APPENDIX
********************************************


*	Table A1: Summasty statistics for government observations
sum sv_23 troop1000_max police1000_max bdbest_ln osv_ln $X2 nopoc nocontrol_gov if actor_type==1

*	Table A2: Summasty statistics for rebel observations
sum sv_23 troop1000_max police1000_max bdbest_ln osv_ln $X2 nopoc nocontrol_reb if actor_type==3

*	Table A3 and A4: Crosstab, is PK more common when SV is high?
gen lsv_23=L.sv_23
tab un lsv_23  if actor_type==1, col chi2
tab un lsv_23  if actor_type==3, col chi2

*	Table A5 and A6: Crosstab, is PK more common when control is high?
tab un control_gov  if actor_type==1, col chi2
tab un control_reb  if actor_type==3, col chi2

*	Table A7: bivariate probit with instrumental variable UNSC membership
eststo clear
eststo: quietly biprobit (sv_23 =  un nocontrol_gov $X6) (un = nocontrol_gov $X6 unsc) if actor_type==1, cl(actorid_conflictid)
eststo: quietly biprobit (sv_23 =  un nocontrol_reb $X6) (un = nocontrol_reb $X6 unsc) if actor_type==3, cl(actorid_conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) title(Table A7: Recursive bivariate probit with instrument) nonumbers ///
mtitles("Model 1: Government sexual violence" "Model 2: Rebel sexual violence" ), using biprobit.rtf ,replace


*	Table A8: Control for sexual abuse by peacekeepers, 1999-2009, H1 PoC mandate
eststo clear
eststo: quietly logit sv_23 sea $X1 L.nopoc L.troops_nopoc $X2 if actor_type==1 & year>1998, cl(conflictid)
eststo: quietly logit sv_23 sea $X1 L.nopoc L.police_nopoc $X2 if actor_type==1 & year>1998, cl(conflictid)
eststo: quietly logit sv_23 sea $X1 L.nopoc L.troops_nopoc $X2 if actor_type==3 & year>1998, cl(conflictid)
eststo: quietly logit sv_23 sea $X1 L.nopoc L.police_nopoc $X2 if actor_type==3 & year>1998, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) title(Table A4: Control for sexual abuse by peacekeepers) nonumbers ///
mtitles("Model 1: Government sexual violence" "Model 2: Government sexual violence" ///
"Model 3: Rebel sexual violence" "Model 4: Rebel sexual violence"), using sea_poc.rtf ,replace

*	Table A9: Control for sexual abuse by peacekeepers, 1999-2009, H2 Control
eststo clear
eststo: quietly logit sv_23 sea $X1 L.nocontrol_gov L.troops_nocontrolgov L.nopoc $X2 if actor_type==1 & year>1998, cl(conflictid)
eststo: quietly logit sv_23 sea $X1 L.nocontrol_gov L.police_nocontrolgov L.nopoc $X2 if actor_type==1 & year>1998, cl(conflictid)
eststo: quietly logit sv_23 sea $X1 L.nocontrol_reb L.troops_nocontrolreb L.nopoc $X2 if actor_type==3 & year>1998, cl(conflictid)
eststo: quietly logit sv_23 sea $X1 L.nocontrol_reb L.police_nocontrolreb L.nopoc $X2 if actor_type==3 & year>1998, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) mtitles("Model 1: Government sexual violence" "Model 2: Government sexual violence" ///
"Model 3: Rebel sexual violence" "Model 4: Rebel sexual violence"), using sea_cont.rtf ,replace


*	Table A10: peacekeeping-sample only, H1 poc mandate 
eststo clear
eststo: quietly logit sv_23  $X1 L.nopoc L.troops_nopoc $X2 if actor_type==1 & l.un==1, cl(conflictid)
eststo: quietly logit sv_23  $X1 L.nopoc L.police_nopoc $X2 if actor_type==1 & l.un==1, cl(conflictid)
eststo: quietly logit sv_23  $X1 L.nopoc L.troops_nopoc $X2 if actor_type==3 & l.un==1, cl(conflictid)
eststo: quietly logit sv_23  $X1 L.nopoc L.police_nopoc $X2 if actor_type==3 & l.un==1, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) mtitles("Model 1: Government sexual violence" "Model 2: Government sexual violence" ///
"Model 3: Rebel sexual violence" "Model 4: Rebel sexual violence"), using pko_poc.rtf ,replace

*	Table A11: peacekeeping-sample only, H2 control 
eststo clear
eststo: quietly logit sv_23  $X1 L.nocontrol_gov L.troops_nocontrolgov L.nopoc $X2 if actor_type==1 & l.un==1, cl(conflictid)
eststo: quietly logit sv_23  $X1 L.nocontrol_gov L.police_nocontrolgov L.nopoc $X2 if actor_type==1 & l.un==1, cl(conflictid)
eststo: quietly logit sv_23  $X1 L.nocontrol_reb L.troops_nocontrolreb L.nopoc $X2 if actor_type==3 & l.un==1, cl(conflictid)
eststo: quietly logit sv_23  $X1 L.nocontrol_reb L.police_nocontrolreb L.nopoc $X2 if actor_type==3 & l.un==1, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) mtitles("Model 1: Government sexual violence" "Model 2: Government sexual violence" ///
"Model 3: Rebel sexual violence" "Model 4: Rebel sexual violence"), using pko_cont.rtf ,replace


*	Table A12: How does the use of sexual violence by one side affect the other? H1
*poc mandate 
eststo clear
eststo: quietly logit sv_23 $X1 L.nopoc L.troops_nopoc $X3 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.police_nopoc $X3 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.troops_nopoc $X3 if actor_type==3, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nopoc L.police_nopoc $X3 if actor_type==3, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) mtitles("Model 1: Government sexual violence" "Model 2: Government sexual violence" ///
"Model 3: Rebel sexual violence" "Model 4: Rebel sexual violence"), using int_poc.rtf ,replace

*	Table A13: How does the use of sexual violence by one side affect the other? H2
eststo clear
eststo: quietly logit sv_23 $X1 L.nocontrol_gov L.troops_nocontrolgov L.nopoc $X3 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_gov L.police_nocontrolgov L.nopoc $X3 if actor_type==1, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_reb L.troops_nocontrolreb L.nopoc $X3 if actor_type==3, cl(conflictid)
eststo: quietly logit sv_23 $X1 L.nocontrol_reb L.police_nocontrolreb L.nopoc $X3 if actor_type==3, cl(conflictid)
esttab, label se ar2 star(+ 0.10 * 0.05 ** 0.001) mtitles("Model 1: Government sexual violence" "Model 2: Government sexual violence" ///
"Model 3: Rebel sexual violence" "Model 4: Rebel sexual violence"), using int_cont.rtf ,replace
